@@ -1,12 +1,12 @@
 #!/bin/bash
 # libmemcached	(http://tangent.org/)
-#	BuildScript for Plamo Linux 4.5
-#			by Jun Kuwamura <juk@linet.gr.jp> on 2008-07-20
+#	BuildScript for Plamo Linux 4.73
+#			by Jun Kuwamura <juk@linet.gr.jp> on 2011-05-21
 # require:
-#	memcached-1.2.x
+#	memcached-1.4.x
 #	libevent-1.4.x
 #
-SRC_URI=http://download.tangent.org/libmemcached-0.22.tar.gz
+SRC_URI=http://download.tangent.org/libmemcached-0.48.tar.gz
 SRC_FILE=${SRC_URI##*/}
 SRC_NAME=${SRC_FILE%%.tar.gz}
 PAC_NAME=${SRC_NAME%%-stable}
@@ -17,7 +17,7 @@ SYS_NAME="${CPU}-${REL}"
 
 PLAMO=/expo/Build
 SRC_DIR=$PLAMO/Archive/network
-PAC_DIR=$PLAMO/Packages/4.5/Network
+PAC_DIR=$PLAMO/Packages/4.7/Memcache
 BUILD_DIR=$PLAMO/memcached
 CUSTOM_DIR=$BUILD_DIR/Custom
 
@@ -63,10 +63,10 @@ chmod -R a+rX,go-w $DOC_DIR/
 cd $WORK
 echo "y
 1
-" | makepkg ${PAC_NAME}.tgz
+" | makepkg ${PAC_NAME}-${SYS_NAME}.tgz
 
 echo -n "$PAC_DIR/${PAC_NAME}-${SYS_NAME}.tgz"
-if `mv -v ${PAC_NAME}.tgz  $PAC_DIR/${PAC_NAME}-${SYS_NAME}.tgz 1>/dev/null 2>&1`; then
+if `mv -v ${PAC_NAME}-${SYS_NAME}.tgz  $PAC_DIR/${PAC_NAME}-${SYS_NAME}.tgz 1>/dev/null 2>&1`; then
   echo " ... done"
 else
   echo " ... false"
